<?php
// $Id: apachesolr_ajax.proxy.inc,v 1.1 2009/10/07 22:23:31 jpmckinney Exp $

/**
 * @file
 * Implements the passthru menu callback.
 */

/**
 * Menu callback for proxying queries. Transforms a Solr query into an
 * apachesolr query, executes the query, and prints out the resulting JSON.
 * @see AjaxSolr.AbstractManager.buildQueryString()
 */
function apachesolr_ajax_proxy_queries() {
  // Basic facet info. Return the top 40 items for each facet and ignore anything with 0 results
  $params = array(
    'facet' => 'true',
    'facet.limit' => 40,
    'facet.sort' => 'true',
    'facet.mincount' => 1,
    'hl' => 'true',
  );

  $pairs = explode('&', $_POST['query']);
  foreach ($pairs as $pair) {
    list($key, $value) = explode('=', $pair, 2);
    if (in_array($key, _apachesolr_ajax_valid_keys()) || preg_match('/\.facet\.date\.(?:start|end|gap)$/', $key)) {
      switch ($key) {
        case 'fl':
        case 'hl.fl':
          $clean = apachesolr_ajax_filter_fields(explode(',', $value));
          $params[$key] = implode(',', $clean);
          break;
        case 'rows':
          $limit = variable_get('apachesolr_ajax_proxy_max_rows', NULL);
          $params[$key] = ($limit && $value > $limit) ? $limit : $value;
          break;
        default:
          $params[$key] = $value;
          break;
      }
    }
    elseif (in_array($key, _apachesolr_ajax_multivalue_keys())) {
      switch ($key) {
        case 'facet.field':
        case 'facet.date':
          if (_apachesolr_ajax_allowed_field($value)) {
            $params[$key][] = $value;
          }
          break;
        case 'fq':
          list($k, $v) = explode(':', $value, 2);
          if (_apachesolr_ajax_allowed_field($k)) {
            $params[$key][] = $value;
          }
        default:
          $params[$key][] = $value;
          break;
      }
    }
    elseif ($key == 'q') {
      $keys = $value;
    }
  }

  $params['json.wrf'] = $_GET['callback'];
  $params['jsoncallback'] = $_GET['callback'];

  $solr = apachesolr_get_solr();
  $response = $solr->search($keys, $params['start'], $params['rows'], $params);

  print $response->getRawResponse();
}

/**
 * Removes fields from the given array if they are not in the list of proxy fields.
 *
 * @param $fields
 *   An array of fields to be filtered.
 * @return
 *   An array of fields after filtering.
 */
function apachesolr_ajax_filter_fields($fields) {
  if (!is_array($fields)) {
    $fields = array($fields);
  }
  $allowed_fields = _apachesolr_ajax_allowed_fields();
  if (!empty($allowed_fields)) {
    return array_intersect($fields, $allowed_fields);
  }
  return $fields;
}

function _apachesolr_ajax_allowed_fields() {
  static $fields = NULL;
  if (is_null($fields)) {
    $fields = array_filter(array_map('trim', explode(',', variable_get('apachesolr_ajax_proxy_fields', ''))));
  }
  return $fields;
}

function _apachesolr_ajax_allowed_field($field) {
  $fields = _apachesolr_ajax_allowed_fields();
  return empty($fields) || in_array($field, $fields);
}

function _apachesolr_ajax_valid_keys() {
  return array('fl', 'rows', 'start', 'sort', 'hl.fl');
}

function _apachesolr_ajax_multivalue_keys() {
  return array('facet.field', 'facet.date', 'fq');
}
