// $Id: ResultWidget.js,v 1.1 2009/10/07 22:23:31 jpmckinney Exp $

(function($) {

/**
 * @expects this.container to contain an h2.
 * @expects this.target to replace itself with a node with the same CSS class.
 */
AjaxSolr.ResultWidget = AjaxSolr.AbstractResultWidget.extend({
  fields: [ 'path_alias', 'path', 'type', 'title', 'uid', 'name', 'homepage', 'created', 'comment_count', 'teaser' ],
  animate: true,

  /**
   * URL of the loading spinner. Optional.
   *
   * @field
   * @public
   */
  spinnerSrc: '',

  startAnimation: function() {
    if (this.spinnerSrc) {
      var img = $('<img class="ajaxsolr-spinner"/>').attr('src', this.spinnerSrc);
      $('.ajaxsolr-result-container').html(img);
    }
  },

  /**
   * @see apachesolr_search_view()
   */
  handleResult: function(data) {
    // at this point, apachesolr_search_view() calls search_data(), which calls
    // apachesolr_search_search(), which returns apachesolr_process_response(),
    // which search_data() then passes through theme('search_results').
    var results = Drupal.theme('search_results', this.preprocessSearchResults(this.processResponse(data)));
    if (parseInt(data.response.numFound)) {
      this.renderResults(data, results);
    }
    else {
      this.renderNoResults(data);
    }
  },

  renderResults: function(data, results) {
    $(this.container).find('h2').text(Drupal.t('Search results'));
    $('.ajaxsolr-result-container').html(results);
  },

  renderNoResults: function(data) {
    $(this.container).find('h2').text(Drupal.t('Your search yielded no results'));
    $('.ajaxsolr-result-container').html(Drupal.searchHelp('search#noresults', Drupal.drupalHelpArg()));
  },

  afterAdditionToManager: function() {
    var div = $('<div class="ajaxsolr-result-container"/>');
    $(this.target).clone().appendTo(div);
    $(this.target).replaceWith(div);

    this._afterAdditionToManager();
  },

  /**
   * Instead of having the child call super, have the parent call the child.
   */
  _afterAdditionToManager: function() {},

  /**
   * @see apachesolr_process_response()
   */
  processResponse: function(response) {
    var results = [];

    var total = parseInt(response.response.numFound);

    if (total > 0) {
      for (var i = 0; i < response.response.docs.length; i++) {
        var doc = response.response.docs[i];

        var extra = [];

        var snippet = '';
        if (response.highlighting && response.highlighting[doc.id][this.manager.hlFl]) {
          snippet = Drupal.theme('apachesolr_search_snippets', doc, response.highlighting[doc.id][this.manager.hlFl]);
        }
        else if (doc.teaser) {
          snippet = Drupal.theme('apachesolr_search_snippets', doc, [ Drupal.truncateUtf8(doc.teaser, 256, true) ]);
        }

        if (doc.body === undefined) {
          doc.body = snippet;
        }

        // Drupal runs the doc through hook_apachesolr_search_result_alter, but
        // we won't have access to any modifications made by those alter's.
        extra.push(Drupal.formatPlural(doc.comment_count, '1 comment', '@count comments'));
        results.push({
          link: Drupal.url(doc.path_alias ? doc.path_alias : doc.path),
          type: doc.type, // calls apachesolr_search_get_type()
          title: doc.title,
          user: Drupal.theme('username', doc),
          date: doc.created,
          node: doc,
          extra: extra,
          score: doc.score,
          snippet: snippet
        });
      }

      // Drupal runs results by reference through hook_apachesolr_process_results,
      // but we won't have access to any modifications made by those alter's.
    }

    return results;
  },

  /**
   * @see search_theme()
   * @see template_preprocess_search_results()
   */
  preprocessSearchResults: function(results) {
    var variables = {};

    variables.search_results = '';
    for (var i = 0; i < results.length; i++) {
      variables.search_results += Drupal.theme('search_result', this.preprocessSearchResult(results[i]));
    }

    return variables;
  },

  /**
   * @see search_theme()
   * @see template_preprocess_search_result()
   */
  preprocessSearchResult: function(result) {
    var variables = {};

    variables.url = result.link; // calls check_url()
    variables.title = Drupal.checkPlain(result.title);

    var info = {};
    if (result.type) {
      info.type = Drupal.checkPlain(result.type);
    }
    if (result.user) {
      info.user = result.user;
    }
    if (result.date) {
      info.date = Drupal.formatDate(result.date, 'small');
    }
    if (result.extra && AjaxSolr.isArray(result.extra)) {
      AjaxSolr.extend(info, result.extra);
    }

    variables.snippet = result.snippet;
    variables.info_split = info;

    var values = [];
    for (var i in info) {
      values.push(info[i]);
    }
    variables.info = values.join(' - ');

    return variables;
  }
});

})(jQuery);
