// $Id: SortWidget.js,v 1.1 2009/10/07 22:23:31 jpmckinney Exp $

/**
 * @expects this.target to be a list.
 */
AjaxSolr.SortWidget = AjaxSolr.AbstractSortWidget.extend({
  /**
   * @see default_sorts() in Solr_Base_Query
   */
  sorts: {
    score: {
      title: Drupal.t('Relevancy'),
      order: 'asc'
    },
    sort_title: {
      title: Drupal.t('Title'),
      order: 'asc'
    },
    type: {
      title: Drupal.t('Type'),
      order: 'asc'
    },
    sort_name: {
      title: Drupal.t('Author'),
      order: 'asc'
    },
    created: {
      title: Drupal.t('Date'),
      order: 'desc'
    }
  },

  /**
   * Reload the widget on each AJAX request.
   */
  handleResult: function(data) {
    if (parseInt(data.response.numFound)) {
      AjaxSolr.theme('list_items', this.target, this.themedLinks());

      $(this.container).show();
    }
    else {
      $(this.container).hide();
    }
  },

  /**
   * @return An array of themed sort links.
   * @see apachesolr_block()
   */
  themedLinks: function() {
    var solrsort = this.sort.split(' ');

    var themedLinks = []
    for (var name in this.sorts) {
      if (this.sorts[name]) {
        var active = solrsort[0] == name, direction = '', newDirection = this.sorts[name].order;
        if (name == 'score') {
          // We only sort by ascending score.
          newDirection = 'asc';
        }
        else if (active) {
          direction = solrsort[1];
          newDirection = solrsort[1] == 'asc' ? 'desc' : 'asc';
        }
        themedLinks.push(Drupal.theme('apachesolr_sort_link', this.sorts[name].title, this.clickHandler(name, newDirection), {}, active, direction));
      }
    }
    return themedLinks;
  },

  /**
   * @param name The name of the sort.
   * @param newDirection the order of the sort.
   * @return The click handler for the sort link.
   */
  clickHandler: function(name, newDirection) {
    var me = this;
    return function() {
      me.sort = name + ' ' + newDirection;
      me.manager.doRequest(0);
      return false;
    }
  }
});
