// $Id: apachesolr.theme.js,v 1.1 2009/10/07 22:23:31 jpmckinney Exp $

/**
 * @see theme_username()
 */
Drupal.theme.prototype.username = function(object) {
  var output;
  if (object.uid && object.name) {
    var name;
    if (object.name.length > 20) {
      name = object.name.substring(0, 15) + '...';
    }
    else {
      name = object.name;
    }

    // assume user_access('access user profiles')
    output = Drupal.l(name, 'user/' + object.uid, { attributes: { title: Drupal.t('View user profile.') }});
  }
  else if (object.name) {
    if (object.homepage) {
      output = Drupal.l(object.name, object.homepage, { attributes: { rel: 'nofollow' }});
    }
    else {
      output = Drupal.checkPlain(object.name);
    }
    output += ' (' + Drupal.t('not verified') + ')';
  }
  else {
    // skip variable_get() call
    output = Drupal.checkPlain(Drupal.t('Anonymous'));
  }

  return output;
}

/**
 * @see modules/system/box.tpl.php
 */
Drupal.theme.prototype.box = function(title, content, region) {
  var output = '<div class="box">';
  if (title) {
    output += '<h2>' + title + '</h2>';
  }
  output += '<div class="content">' + content + '</div></div>';

  return output;
}

/**
 * @see modules/search/search-results.tpl.php
 */
Drupal.theme.prototype.search_results = function(vars) {
  var output = '<dl class="search-results">';
  output += vars.search_results;
  output += '</dl>';

  return output;
}

/**
 * @see modules/search/search-result.tpl.php
 */
Drupal.theme.prototype.search_result = function(vars) {
  var output = '<dt class="title"><a href="' + vars.url + '">' + vars.title + '</a></dt><dd>';
  if (vars.snippet) {
    output += '<p class="search-snippet">' + vars.snippet + '</p>';
  }
  if (vars.info) {
    output += '<p class="search-info">' + vars.info + '</p>';
  }
  output += '</dd>';

  return output;
}

/**
 * @see theme_apachesolr_search_snippets()
 */
Drupal.theme.prototype.apachesolr_search_snippets = function(doc, snippets) {
  return snippets.join(' ... ') + ' ...';
}

/**
 * @see theme_apachesolr_facet_link()
 */
Drupal.theme.prototype.apachesolr_facet_link = function(facetText, handler, options, count, active, numFound) {
  options = options || {}, options.attributes = options.attributes || {}, options.attributes['class'] = options.attributes['class'] || [];

  options.attributes['class'].push('apachesolr-facet');
  if (active) {
    options.attributes['class'].push('active');
  }
  options.attributes['class'] = options.attributes['class'].join(' ');
  return [ Drupal.apachesolr_l(facetText + ' (' + count + ')', handler, options) ];
}

/**
 * @see theme_apachesolr_unclick_link()
 */
Drupal.theme.prototype.apachesolr_unclick_link = function(facetText, handler, options) {
  options = options || {}, options.attributes = options.attributes || {};
  if (options.html) {
    delete options.html;
  }
  else {
    facetText = Drupal.checkPlain(facetText);
  }
  options.attributes['class'] = 'apachesolr-unclick';
  return [ Drupal.apachesolr_l('(-)', handler, options), ' ' + facetText ];
}

/**
 * @see theme_apachesolr_sort_link()
 */
Drupal.theme.prototype.apachesolr_sort_link = function(text, handler, options, active, direction) {
  options = options || {}, options.attributes = options.attributes || {};

  var icon = '';
  if (direction) {
    icon = ' ' + Drupal.theme('tableSortIndicator', direction);
  }
  if (active) {
    if (options.attributes['class']) {
      options.attributes['class'] += ' active';
    }
    else {
      options.attributes['class'] = 'active';
    }
  }
  return [ icon, Drupal.apachesolr_l(text, handler, options) ];
}
